==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/managednetworkfabric/kotlin/NetworkFabricController.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetworkfabric.kotlin

import com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.ExpressRouteConnectionInformationResponse
import com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.InfrastructureServicesResponse
import com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.ManagedResourceGroupConfigurationResponse
import com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.WorkloadServicesResponse
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.collections.Map
import com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.ExpressRouteConnectionInformationResponse.Companion.toKotlin as expressRouteConnectionInformationResponseToKotlin
import com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.InfrastructureServicesResponse.Companion.toKotlin as infrastructureServicesResponseToKotlin
import com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.ManagedResourceGroupConfigurationResponse.Companion.toKotlin as managedResourceGroupConfigurationResponseToKotlin
import com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.SystemDataResponse.Companion.toKotlin as systemDataResponseToKotlin
import com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.WorkloadServicesResponse.Companion.toKotlin as workloadServicesResponseToKotlin

/**
 * Builder for [NetworkFabricController].
 */
@PulumiTagMarker
public class NetworkFabricControllerResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: NetworkFabricControllerArgs = NetworkFabricControllerArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend NetworkFabricControllerArgsBuilder.() -> Unit) {
        val builder = NetworkFabricControllerArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): NetworkFabricController {
        val builtJavaResource =
            com.pulumi.azurenative.managednetworkfabric.NetworkFabricController(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return NetworkFabricController(builtJavaResource)
    }
}

/**
 * The NetworkFabricController resource definition.
 * Azure REST API version: 2023-02-01-preview. Prior API version in Azure Native 1.x: 2023-02-01-preview.
 * Other available API versions: 2023-06-15.
 * ## Example Usage
 * ### NetworkFabricControllers_Create_MaximumSet_Gen
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var networkFabricController = new AzureNative.ManagedNetworkFabric.NetworkFabricController("networkFabricController", new()
 *     {
 *         Annotation = "lab 1",
 *         InfrastructureExpressRouteConnections = new[]
 *         {
 *             new AzureNative.ManagedNetworkFabric.Inputs.ExpressRouteConnectionInformationArgs
 *             {
 *                 ExpressRouteAuthorizationKey = "xxxxxxx",
 *                 ExpressRouteCircuitId = "/subscriptions/xxxxx/resourceGroups/resourceGroupName/providers/Microsoft.Network/expressRouteCircuits/expressRouteCircuitName",
 *             },
 *         },
 *         Ipv4AddressSpace = "172.253.0.0/19",
 *         Location = "eastus",
 *         ManagedResourceGroupConfiguration = new AzureNative.ManagedNetworkFabric.Inputs.ManagedResourceGroupConfigurationArgs
 *         {
 *             Location = "eastus",
 *             Name = "managedResourceGroupName",
 *         },
 *         NetworkFabricControllerName = "NetworkControllerName",
 *         ResourceGroupName = "resourceGroupName",
 *         WorkloadExpressRouteConnections = new[]
 *         {
 *             new AzureNative.ManagedNetworkFabric.Inputs.ExpressRouteConnectionInformationArgs
 *             {
 *                 ExpressRouteAuthorizationKey = "xxxxx",
 *                 ExpressRouteCircuitId = "/subscriptions/xxxxx/resourceGroups/resourceGroupName/providers/Microsoft.Network/expressRouteCircuits/expressRouteCircuitName",
 *             },
 *         },
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/managednetworkfabric/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := managednetworkfabric.NewNetworkFabricController(ctx, "networkFabricController", &managednetworkfabric.NetworkFabricControllerArgs{
 * 			Annotation: pulumi.String("lab 1"),
 * 			InfrastructureExpressRouteConnections: []managednetworkfabric.ExpressRouteConnectionInformationArgs{
 * 				{
 * 					ExpressRouteAuthorizationKey: pulumi.String("xxxxxxx"),
 * 					ExpressRouteCircuitId:        pulumi.String("/subscriptions/xxxxx/resourceGroups/resourceGroupName/providers/Microsoft.Network/expressRouteCircuits/expressRouteCircuitName"),
 * 				},
 * 			},
 * 			Ipv4AddressSpace: pulumi.String("172.253.0.0/19"),
 * 			Location:         pulumi.String("eastus"),
 * 			ManagedResourceGroupConfiguration: &managednetworkfabric.ManagedResourceGroupConfigurationArgs{
 * 				Location: pulumi.String("eastus"),
 * 				Name:     pulumi.String("managedResourceGroupName"),
 * 			},
 * 			NetworkFabricControllerName: pulumi.String("NetworkControllerName"),
 * 			ResourceGroupName:           pulumi.String("resourceGroupName"),
 * 			WorkloadExpressRouteConnections: []managednetworkfabric.ExpressRouteConnectionInformationArgs{
 * 				{
 * 					ExpressRouteAuthorizationKey: pulumi.String("xxxxx"),
 * 					ExpressRouteCircuitId:        pulumi.String("/subscriptions/xxxxx/resourceGroups/resourceGroupName/providers/Microsoft.Network/expressRouteCircuits/expressRouteCircuitName"),
 * 				},
 * 			},
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.managednetworkfabric.NetworkFabricController;
 * import com.pulumi.azurenative.managednetworkfabric.NetworkFabricControllerArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var networkFabricController = new NetworkFabricController("networkFabricController", NetworkFabricControllerArgs.builder()
 *             .annotation("lab 1")
 *             .infrastructureExpressRouteConnections(Map.ofEntries(
 *                 Map.entry("expressRouteAuthorizationKey", "xxxxxxx"),
 *                 Map.entry("expressRouteCircuitId", "/subscriptions/xxxxx/resourceGroups/resourceGroupName/providers/Microsoft.Network/expressRouteCircuits/expressRouteCircuitName")
 *             ))
 *             .ipv4AddressSpace("172.253.0.0/19")
 *             .location("eastus")
 *             .managedResourceGroupConfiguration(Map.ofEntries(
 *                 Map.entry("location", "eastus"),
 *                 Map.entry("name", "managedResourceGroupName")
 *             ))
 *             .networkFabricControllerName("NetworkControllerName")
 *             .resourceGroupName("resourceGroupName")
 *             .workloadExpressRouteConnections(Map.ofEntries(
 *                 Map.entry("expressRouteAuthorizationKey", "xxxxx"),
 *                 Map.entry("expressRouteCircuitId", "/subscriptions/xxxxx/resourceGroups/resourceGroupName/providers/Microsoft.Network/expressRouteCircuits/expressRouteCircuitName")
 *             ))
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:managednetworkfabric:NetworkFabricController NetworkFabricName /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.ManagedNetworkFabric/networkFabricControllers/{networkFabricControllerName}
 * ```
 */
public class NetworkFabricController internal constructor(
    override val javaResource: com.pulumi.azurenative.managednetworkfabric.NetworkFabricController,
) : KotlinCustomResource(javaResource, NetworkFabricControllerMapper) {
    /**
     * Switch configuration description.
     */
    public val `annotation`: Output<String>?
        get() = javaResource.`annotation`().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * As part of an update, the Infrastructure ExpressRoute CircuitID should be provided to create and Provision a NFC. This Express route is dedicated for Infrastructure services. (This is a Mandatory attribute)
     */
    public val infrastructureExpressRouteConnections:
        Output<List<ExpressRouteConnectionInformationResponse>>?
        get() = javaResource.infrastructureExpressRouteConnections().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.let({ args0 ->
                        expressRouteConnectionInformationResponseToKotlin(args0)
                    })
                })
            }).orElse(null)
        })

    /**
     * InfrastructureServices IP ranges.
     */
    public val infrastructureServices: Output<InfrastructureServicesResponse>
        get() = javaResource.infrastructureServices().applyValue({ args0 ->
            args0.let({ args0 ->
                infrastructureServicesResponseToKotlin(args0)
            })
        })

    /**
     * IPv4 Network Fabric Controller Address Space.
     */
    public val ipv4AddressSpace: Output<String>?
        get() = javaResource.ipv4AddressSpace().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * IPv6 Network Fabric Controller Address Space.
     */
    public val ipv6AddressSpace: Output<String>?
        get() = javaResource.ipv6AddressSpace().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * The geo-location where the resource lives
     */
    public val location: Output<String>
        get() = javaResource.location().applyValue({ args0 -> args0 })

    /**
     * Managed Resource Group configuration properties.
     */
    public val managedResourceGroupConfiguration: Output<ManagedResourceGroupConfigurationResponse>?
        get() = javaResource.managedResourceGroupConfiguration().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 ->
                    managedResourceGroupConfigurationResponseToKotlin(args0)
                })
            }).orElse(null)
        })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * The NF-ID will be an input parameter used by the NF to link and get associated with the parent NFC Service.
     */
    public val networkFabricIds: Output<List<String>>
        get() = javaResource.networkFabricIds().applyValue({ args0 -> args0.map({ args0 -> args0 }) })

    /**
     * The Operational Status would always be NULL. Look only in to the Provisioning state for the latest status.
     */
    public val operationalState: Output<String>
        get() = javaResource.operationalState().applyValue({ args0 -> args0 })

    /**
     * Provides you the latest status of the NFC service, whether it is Accepted, updating, Succeeded or Failed. During this process, the states keep changing based on the status of NFC provisioning.
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 ->
            args0.let({ args0 ->
                systemDataResponseToKotlin(args0)
            })
        })

    /**
     * Resource tags.
     */
    public val tags: Output<Map<String, String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.key.to(args0.value)
                }).toMap()
            }).orElse(null)
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })

    /**
     * As part of an update, the workload ExpressRoute CircuitID should be provided to create and Provision a NFC. This Express route is dedicated for Workload services. (This is a Mandatory attribute).
     */
    public val workloadExpressRouteConnections:
        Output<List<ExpressRouteConnectionInformationResponse>>?
        get() = javaResource.workloadExpressRouteConnections().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.let({ args0 ->
                        expressRouteConnectionInformationResponseToKotlin(args0)
                    })
                })
            }).orElse(null)
        })

    /**
     * A workload management network is required for all the tenant (workload) traffic. This traffic is only dedicated for Tenant workloads which are required to access internet or any other MSFT/Public endpoints.
     */
    public val workloadManagementNetwork: Output<Boolean>
        get() = javaResource.workloadManagementNetwork().applyValue({ args0 -> args0 })

    /**
     * WorkloadServices IP ranges.
     */
    public val workloadServices: Output<WorkloadServicesResponse>
        get() = javaResource.workloadServices().applyValue({ args0 ->
            args0.let({ args0 ->
                workloadServicesResponseToKotlin(args0)
            })
        })
}

public object NetworkFabricControllerMapper : ResourceMapper<NetworkFabricController> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.managednetworkfabric.NetworkFabricController::class == javaResource::class

    override fun map(javaResource: Resource): NetworkFabricController =
        NetworkFabricController(
            javaResource as
                com.pulumi.azurenative.managednetworkfabric.NetworkFabricController,
        )
}

/**
 * @see [NetworkFabricController].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [NetworkFabricController].
 */
public suspend fun networkFabricController(
    name: String,
    block: suspend NetworkFabricControllerResourceBuilder.() -> Unit,
): NetworkFabricController {
    val builder = NetworkFabricControllerResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [NetworkFabricController].
 * @param name The _unique_ name of the resulting resource.
 */
public fun networkFabricController(name: String): NetworkFabricController {
    val builder = NetworkFabricControllerResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/managednetworkfabric/kotlin/NetworkFabricController.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetworkfabric.kotlin

import com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.ExpressRouteConnectionInformationResponse
import com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.InfrastructureServicesResponse
import com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.ManagedResourceGroupConfigurationResponse
import com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.WorkloadServicesResponse
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.collections.Map
import com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.ExpressRouteConnectionInformationResponse.Companion.toKotlin as expressRouteConnectionInformationResponseToKotlin
import com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.InfrastructureServicesResponse.Companion.toKotlin as infrastructureServicesResponseToKotlin
import com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.ManagedResourceGroupConfigurationResponse.Companion.toKotlin as managedResourceGroupConfigurationResponseToKotlin
import com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.SystemDataResponse.Companion.toKotlin as systemDataResponseToKotlin
import com.pulumi.azurenative.managednetworkfabric.kotlin.outputs.WorkloadServicesResponse.Companion.toKotlin as workloadServicesResponseToKotlin

/**
 * Builder for [NetworkFabricController].
 */
@PulumiTagMarker
public class NetworkFabricControllerResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: NetworkFabricControllerArgs = NetworkFabricControllerArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend NetworkFabricControllerArgsBuilder.() -> Unit) {
        val builder = NetworkFabricControllerArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): NetworkFabricController {
        val builtJavaResource =
            com.pulumi.azurenative.managednetworkfabric.NetworkFabricController(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return NetworkFabricController(builtJavaResource)
    }
}

/**
 * The NetworkFabricController resource definition.
 * Azure REST API version: 2023-02-01-preview. Prior API version in Azure Native 1.x: 2023-02-01-preview.
 * Other available API versions: 2023-06-15.
 * ## Example Usage
 * ### NetworkFabricControllers_Create_MaximumSet_Gen
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var networkFabricController = new AzureNative.ManagedNetworkFabric.NetworkFabricController("networkFabricController", new()
 *     {
 *         Annotation = "lab 1",
 *         InfrastructureExpressRouteConnections = new[]
 *         {
 *             new AzureNative.ManagedNetworkFabric.Inputs.ExpressRouteConnectionInformationArgs
 *             {
 *                 ExpressRouteAuthorizationKey = "xxxxxxx",
 *                 ExpressRouteCircuitId = "/subscriptions/xxxxx/resourceGroups/resourceGroupName/providers/Microsoft.Network/expressRouteCircuits/expressRouteCircuitName",
 *             },
 *         },
 *         Ipv4AddressSpace = "172.253.0.0/19",
 *         Location = "eastus",
 *         ManagedResourceGroupConfiguration = new AzureNative.ManagedNetworkFabric.Inputs.ManagedResourceGroupConfigurationArgs
 *         {
 *             Location = "eastus",
 *             Name = "managedResourceGroupName",
 *         },
 *         NetworkFabricControllerName = "NetworkControllerName",
 *         ResourceGroupName = "resourceGroupName",
 *         WorkloadExpressRouteConnections = new[]
 *         {
 *             new AzureNative.ManagedNetworkFabric.Inputs.ExpressRouteConnectionInformationArgs
 *             {
 *                 ExpressRouteAuthorizationKey = "xxxxx",
 *                 ExpressRouteCircuitId = "/subscriptions/xxxxx/resourceGroups/resourceGroupName/providers/Microsoft.Network/expressRouteCircuits/expressRouteCircuitName",
 *             },
 *         },
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/managednetworkfabric/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := managednetworkfabric.NewNetworkFabricController(ctx, "networkFabricController", &managednetworkfabric.NetworkFabricControllerArgs{
 * 			Annotation: pulumi.String("lab 1"),
 * 			InfrastructureExpressRouteConnections: managednetworkfabric.ExpressRouteConnectionInformationArray{
 * 				&managednetworkfabric.ExpressRouteConnectionInformationArgs{
 * 					ExpressRouteAuthorizationKey: pulumi.String("xxxxxxx"),
 * 					ExpressRouteCircuitId:        pulumi.String("/subscriptions/xxxxx/resourceGroups/resourceGroupName/providers/Microsoft.Network/expressRouteCircuits/expressRouteCircuitName"),
 * 				},
 * 			},
 * 			Ipv4AddressSpace: pulumi.String("172.253.0.0/19"),
 * 			Location:         pulumi.String("eastus"),
 * 			ManagedResourceGroupConfiguration: &managednetworkfabric.ManagedResourceGroupConfigurationArgs{
 * 				Location: pulumi.String("eastus"),
 * 				Name:     pulumi.String("managedResourceGroupName"),
 * 			},
 * 			NetworkFabricControllerName: pulumi.String("NetworkControllerName"),
 * 			ResourceGroupName:           pulumi.String("resourceGroupName"),
 * 			WorkloadExpressRouteConnections: managednetworkfabric.ExpressRouteConnectionInformationArray{
 * 				&managednetworkfabric.ExpressRouteConnectionInformationArgs{
 * 					ExpressRouteAuthorizationKey: pulumi.String("xxxxx"),
 * 					ExpressRouteCircuitId:        pulumi.String("/subscriptions/xxxxx/resourceGroups/resourceGroupName/providers/Microsoft.Network/expressRouteCircuits/expressRouteCircuitName"),
 * 				},
 * 			},
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.managednetworkfabric.NetworkFabricController;
 * import com.pulumi.azurenative.managednetworkfabric.NetworkFabricControllerArgs;
 * import com.pulumi.azurenative.managednetworkfabric.inputs.ExpressRouteConnectionInformationArgs;
 * import com.pulumi.azurenative.managednetworkfabric.inputs.ManagedResourceGroupConfigurationArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var networkFabricController = new NetworkFabricController("networkFabricController", NetworkFabricControllerArgs.builder()
 *             .annotation("lab 1")
 *             .infrastructureExpressRouteConnections(ExpressRouteConnectionInformationArgs.builder()
 *                 .expressRouteAuthorizationKey("xxxxxxx")
 *                 .expressRouteCircuitId("/subscriptions/xxxxx/resourceGroups/resourceGroupName/providers/Microsoft.Network/expressRouteCircuits/expressRouteCircuitName")
 *                 .build())
 *             .ipv4AddressSpace("172.253.0.0/19")
 *             .location("eastus")
 *             .managedResourceGroupConfiguration(ManagedResourceGroupConfigurationArgs.builder()
 *                 .location("eastus")
 *                 .name("managedResourceGroupName")
 *                 .build())
 *             .networkFabricControllerName("NetworkControllerName")
 *             .resourceGroupName("resourceGroupName")
 *             .workloadExpressRouteConnections(ExpressRouteConnectionInformationArgs.builder()
 *                 .expressRouteAuthorizationKey("xxxxx")
 *                 .expressRouteCircuitId("/subscriptions/xxxxx/resourceGroups/resourceGroupName/providers/Microsoft.Network/expressRouteCircuits/expressRouteCircuitName")
 *                 .build())
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:managednetworkfabric:NetworkFabricController NetworkFabricName /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.ManagedNetworkFabric/networkFabricControllers/{networkFabricControllerName}
 * ```
 */
public class NetworkFabricController internal constructor(
    override val javaResource: com.pulumi.azurenative.managednetworkfabric.NetworkFabricController,
) : KotlinCustomResource(javaResource, NetworkFabricControllerMapper) {
    /**
     * Switch configuration description.
     */
    public val `annotation`: Output<String>?
        get() = javaResource.`annotation`().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * As part of an update, the Infrastructure ExpressRoute CircuitID should be provided to create and Provision a NFC. This Express route is dedicated for Infrastructure services. (This is a Mandatory attribute)
     */
    public val infrastructureExpressRouteConnections:
        Output<List<ExpressRouteConnectionInformationResponse>>?
        get() = javaResource.infrastructureExpressRouteConnections().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.let({ args0 ->
                        expressRouteConnectionInformationResponseToKotlin(args0)
                    })
                })
            }).orElse(null)
        })

    /**
     * InfrastructureServices IP ranges.
     */
    public val infrastructureServices: Output<InfrastructureServicesResponse>
        get() = javaResource.infrastructureServices().applyValue({ args0 ->
            args0.let({ args0 ->
                infrastructureServicesResponseToKotlin(args0)
            })
        })

    /**
     * IPv4 Network Fabric Controller Address Space.
     */
    public val ipv4AddressSpace: Output<String>?
        get() = javaResource.ipv4AddressSpace().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * IPv6 Network Fabric Controller Address Space.
     */
    public val ipv6AddressSpace: Output<String>?
        get() = javaResource.ipv6AddressSpace().applyValue({ args0 ->
            args0.map({ args0 ->
                args0
            }).orElse(null)
        })

    /**
     * The geo-location where the resource lives
     */
    public val location: Output<String>
        get() = javaResource.location().applyValue({ args0 -> args0 })

    /**
     * Managed Resource Group configuration properties.
     */
    public val managedResourceGroupConfiguration: Output<ManagedResourceGroupConfigurationResponse>?
        get() = javaResource.managedResourceGroupConfiguration().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 ->
                    managedResourceGroupConfigurationResponseToKotlin(args0)
                })
            }).orElse(null)
        })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * The NF-ID will be an input parameter used by the NF to link and get associated with the parent NFC Service.
     */
    public val networkFabricIds: Output<List<String>>
        get() = javaResource.networkFabricIds().applyValue({ args0 -> args0.map({ args0 -> args0 }) })

    /**
     * The Operational Status would always be NULL. Look only in to the Provisioning state for the latest status.
     */
    public val operationalState: Output<String>
        get() = javaResource.operationalState().applyValue({ args0 -> args0 })

    /**
     * Provides you the latest status of the NFC service, whether it is Accepted, updating, Succeeded or Failed. During this process, the states keep changing based on the status of NFC provisioning.
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 ->
            args0.let({ args0 ->
                systemDataResponseToKotlin(args0)
            })
        })

    /**
     * Resource tags.
     */
    public val tags: Output<Map<String, String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.key.to(args0.value)
                }).toMap()
            }).orElse(null)
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })

    /**
     * As part of an update, the workload ExpressRoute CircuitID should be provided to create and Provision a NFC. This Express route is dedicated for Workload services. (This is a Mandatory attribute).
     */
    public val workloadExpressRouteConnections:
        Output<List<ExpressRouteConnectionInformationResponse>>?
        get() = javaResource.workloadExpressRouteConnections().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.let({ args0 ->
                        expressRouteConnectionInformationResponseToKotlin(args0)
                    })
                })
            }).orElse(null)
        })

    /**
     * A workload management network is required for all the tenant (workload) traffic. This traffic is only dedicated for Tenant workloads which are required to access internet or any other MSFT/Public endpoints.
     */
    public val workloadManagementNetwork: Output<Boolean>
        get() = javaResource.workloadManagementNetwork().applyValue({ args0 -> args0 })

    /**
     * WorkloadServices IP ranges.
     */
    public val workloadServices: Output<WorkloadServicesResponse>
        get() = javaResource.workloadServices().applyValue({ args0 ->
            args0.let({ args0 ->
                workloadServicesResponseToKotlin(args0)
            })
        })
}

public object NetworkFabricControllerMapper : ResourceMapper<NetworkFabricController> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.managednetworkfabric.NetworkFabricController::class == javaResource::class

    override fun map(javaResource: Resource): NetworkFabricController =
        NetworkFabricController(
            javaResource as
                com.pulumi.azurenative.managednetworkfabric.NetworkFabricController,
        )
}

/**
 * @see [NetworkFabricController].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [NetworkFabricController].
 */
public suspend fun networkFabricController(
    name: String,
    block: suspend NetworkFabricControllerResourceBuilder.() -> Unit,
): NetworkFabricController {
    val builder = NetworkFabricControllerResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [NetworkFabricController].
 * @param name The _unique_ name of the resulting resource.
 */
public fun networkFabricController(name: String): NetworkFabricController {
    val builder = NetworkFabricControllerResourceBuilder()
    builder.name(name)
    return builder.build()
}
